import type {AuthProvider} from '@refinedev/core'
import axios, {AxiosError} from 'axios'

// import {BACKEND_URL} from './lib/constants'
const API_URL = 'https://wn.krbl.ru'

export const TOKEN_KEY = 'refine-auth'

class AuthError extends Error {
  constructor(message: string) {
    super(message)
    this.name = 'AuthError'
  }
}

const MOCK_USER = {
  email: 'test@wn.ru',
  password: 'testwn',
  name: 'Константин Иванов',
  avatar: 'https://i.pravatar.cc/300',
  // roles: ['admin'],
}

export const authProvider: AuthProvider = {
  login: async ({email, password}) => {
    try {
      if (email === MOCK_USER.email && password === MOCK_USER.password) {
        const mockResponse = {
          token: 'mock-jwt-token',
          user: MOCK_USER,
        }

        localStorage.setItem(TOKEN_KEY, mockResponse.token)
        localStorage.setItem('user', JSON.stringify(mockResponse.user))

        return {
          success: true,
          redirectTo: '/',
        }
      }

      // If not mock user, try real API
      const response = await axios.post(`${API_URL}/auth/login`, {
        email,
        password,
      })

      if (response.data.token) {
        localStorage.setItem(TOKEN_KEY, response.data.token)
        localStorage.setItem('user', JSON.stringify(response.data.user))

        return {
          success: true,
          redirectTo: '/',
        }
      }

      throw new AuthError('Неверный email или пароль')
    } catch (error) {
      return {
        success: false,
        error: new AuthError('Неверный email или пароль'),
      }
    }
  },
  logout: async () => {
    try {
      await axios.post(
        `${API_URL}/auth/logout`,
        {},
        {
          headers: {
            Authorization: `Bearer ${localStorage.getItem(TOKEN_KEY)}`,
          },
        },
      )
    } catch (error) {
      console.error('Ошибка при выходе:', error)
    }

    localStorage.removeItem(TOKEN_KEY)
    localStorage.removeItem('user')
    return {
      success: true,
      redirectTo: '/login',
    }
  },
  check: async () => {
    const token = localStorage.getItem(TOKEN_KEY)
    const user = localStorage.getItem('user')

    if (!token) {
      return {
        authenticated: false,
        redirectTo: '/login',
      }
    }

    // If using mock token, skip API verification
    if (token === 'mock-jwt-token' && user) {
      return {
        authenticated: true,
      }
    }

    // For real tokens, verify with API
    try {
      const response = await axios.get(`${API_URL}/auth/me`, {
        headers: {
          Authorization: `Bearer ${token}`,
        },
      })

      if (response.status === 200) {
        return {
          authenticated: true,
        }
      }
    } catch (error) {
      localStorage.removeItem(TOKEN_KEY)
      localStorage.removeItem('user')
      return {
        authenticated: false,
        redirectTo: '/login',
        error: new AuthError('Сессия истекла, пожалуйста, войдите снова'),
      }
    }

    return {
      authenticated: false,
      redirectTo: '/login',
      error: new AuthError('Пожалуйста, войдите в систему'),
    }
  },
  getPermissions: async () => {
    const token = localStorage.getItem(TOKEN_KEY)
    if (!token) return null

    try {
      const response = await axios.get(`${API_URL}/auth/permissions`, {
        headers: {
          Authorization: `Bearer ${token}`,
        },
      })
      return response.data.permissions
    } catch (error) {
      return null
    }
  },
  getIdentity: async () => {
    const user = localStorage.getItem('user')
    if (user) {
      return JSON.parse(user)
    }
    return null
  },
  onError: async (error) => {
    console.error('Ошибка:', error)
    const status = (error as AxiosError)?.response?.status
    if (status === 401 || status === 403) {
      localStorage.removeItem(TOKEN_KEY)
      localStorage.removeItem('user')
      return {
        logout: true,
        redirectTo: '/login',
        error: new AuthError('Сессия истекла, пожалуйста, войдите снова'),
      }
    }
    return {error}
  },
}
